open

Function open 

pub fn open(
    workspace: &Path,
    session_id: &str,
) -> Result<SessionEventLog, SessionStoreError>
Open (creating if necessary) the event log for a session.

This is the canonical entry point for recording a session’s events. The returned SessionEventLog is cheap to clone (internally Arc-free but the file handle is shared via an internal mutex) and supports concurrent append calls from the runloop’s event sink.