pub enum MilestoneStatus {
Pending,
InProgress,
Done,
Blocked,
}Expand description
Lifecycle status of a single milestone toward the session goal.
Variants
Pending
Not yet started.
InProgress
Actively being worked on this/last turn.
Done
Completed and verified.
Blocked
Blocked — cannot proceed without external input or a replan.
Implementations
Sourceimpl MilestoneStatus
impl MilestoneStatus
Sourcepub fn is_terminal(&self) -> bool
pub fn is_terminal(&self) -> bool
Whether this status counts as forward progress toward completion.